# 文件操作的常用函数包
### 集合了常用的文件处理模块
#### 具体如下:
- 文件夹_创建
- 文件夹_扫描
- 文件_扫描 : 可指定文件类型
- 文件_大小 : 返回MB
- 磁盘_剩余空间: 返回GB
- 移动硬盘_识别
- 表格数据_转化为网络流: fastapi后端服务
- 项目_根目录: 获取项目当前所在的根目录
- ZIP内文件直接读取: 读取zip内文件, 不需要解压

所有函数名同上, 为中文


